summaryrefslogtreecommitdiffstats
path: root/libkdepim/kregexp3.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kregexp3.cpp')
-rw-r--r--libkdepim/kregexp3.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/libkdepim/kregexp3.cpp b/libkdepim/kregexp3.cpp
index f34dad33..87827e07 100644
--- a/libkdepim/kregexp3.cpp
+++ b/libkdepim/kregexp3.cpp
@@ -19,11 +19,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this library with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -38,12 +38,12 @@
#endif
TQString KRegExp3::tqreplace( const TQString & str,
- const TQString & tqreplacementStr,
+ const TQString & replacementStr,
int start, bool global )
{
int oldpos, pos;
//-------- parsing the tqreplacementStr into
//-------- literal parts and backreferences:
TQStringList literalStrs;
TQValueList<int> backRefs;
@@ -55,20 +55,20 @@ TQString KRegExp3::tqreplace( const TQString & str,
TQRegExp brx("\\");
#ifdef DEBUG_KREGEXP3
- kdDebug() << "Analyzing tqreplacementStr: \"" + tqreplacementStr + "\"" << endl;
+ kdDebug() << "Analyzing replacementStr: \"" + replacementStr + "\"" << endl;
#endif
oldpos = 0;
pos = 0;
while ( true ) {
- pos = rx.search( tqreplacementStr, pos );
+ pos = rx.search( replacementStr, pos );
#ifdef DEBUG_KREGEXP3
kdDebug() << TQString(" Found match at pos %1").arg(pos) << endl;
#endif
if ( pos < 0 ) {
- literalStrs << tqreplacementStr.mid( oldpos )
+ literalStrs << replacementStr.mid( oldpos )
.tqreplace( bbrx, "\\" )
.tqreplace( brx, "" );
#ifdef DEBUG_KREGEXP3
@@ -76,7 +76,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
#endif
break;
} else {
- literalStrs << tqreplacementStr.mid( oldpos, pos-oldpos )
+ literalStrs << replacementStr.mid( oldpos, pos-oldpos )
.tqreplace( bbrx, "\\" )
.tqreplace( brx, "" );
#ifdef DEBUG_KREGEXP3
@@ -101,12 +101,12 @@ TQString KRegExp3::tqreplace( const TQString & str,
}
#ifdef DEBUG_KREGEXP3
- kdDebug() << "Finished the analysis of tqreplacementStr!" << endl;
+ kdDebug() << "Finished the analysis of replacementStr!" << endl;
#endif
Q_ASSERT( literalStrs.count() == backRefs.count() + 1 );
//-------- actual construction of the
- //-------- resulting QString
+ //-------- resulting TQString
TQString result = "";
oldpos = 0;
pos = start;
@@ -145,7 +145,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
iIt != backRefs.end() ; ++sIt, ++iIt ) {
result += (*sIt);
#ifdef DEBUG_KREGEXP3
- kdDebug() << " Adding literal tqreplacement part:" << endl;
+ kdDebug() << " Adding literal replacement part:" << endl;
kdDebug() << " result == \"" + result + "\"" << endl;
#endif
result += cap( (*iIt) );
@@ -156,7 +156,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
}
result += (*sIt);
#ifdef DEBUG_KREGEXP3
- kdDebug() << " Adding literal tqreplacement part:" << endl;
+ kdDebug() << " Adding literal replacement part:" << endl;
kdDebug() << " result == \"" + result + "\"" << endl;
#endif
}
@@ -173,7 +173,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
oldpos = pos;
if ( !global ) {
- // only tqreplace the first occurrence, so stop here:
+ // only replace the first occurrence, so stop here:
result += str.mid( oldpos );
break;
}
@@ -38,12 +38,12 @@
{
int oldpos, pos;
- //-------- parsing the tqreplacementStr into
+ //-------- parsing the replacementStr into
//-------- literal parts and backreferences:
TQStringList literalStrs;